.. _citations:

========
Citation
========

How to cite Pharmpy and pharmr
==============================

Rikard Nordgren, Sebastian Ueckert, Stella Belin, Gunnar Yngman, Simon Carter, Simon Buatois, João A. Abrantes, Andrew C. Hooker, Mats O. Karlsson, "Pharmpy and assemblerr - Two novel tools to simplify the model building process in NONMEM", PAGE 29 (2021) Abstr 9656 [www.page-meeting.org/?abstract=9656]
